@@ -5,7 +5,7 @@ use strict;
 use warnings;
 
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 
 #
@@ -921,7 +921,7 @@ sub lookup_obj
 #
 # acc_lookup
 #
-# usage:    $tree_ref->lookup($object)
+# usage:    $tree_ref->acc_lookup($object, $partial_cmp_func, $exact_cmp_func)
 #
 # accumulative lookup, returns a list of all
 # items whose keys satisfy the match function for the key for $object.
@@ -1125,6 +1125,21 @@ sub get_list
     return @objs;
 }
 
+#
+# get_root
+#
+# returns reference to object at root node.
+#
+#
+sub get_root
+{
+    my ($self) = @_;            
+    return $self->{_node}->{_obj};
+}
+
+
+
+
 #
 # get_size
 #
@@ -1619,6 +1634,32 @@ Removes items from the tree.
 
 
 
+=head2 lookup()
+
+    my $found_thing = $avltree->lookup($thing);
+
+Looks for $thing in the tree, returns reference to $thing if found, or nil if not found.
+
+
+
+
+=head2 acc_lookup()
+
+    my @found_things = $avltree->acc_lookup($thing, $partial_cmp_func, $precise_cmp_func);
+
+Accumulative lookup, returns a list of all items whose keys satisfy the match function for the key for $object. 
+For example, suppose you have a "relaxed" compare function such as:
+
+    $word->compare_up_to($arg_word);
+
+which returns true if the argument word is a proper 'superstring' of $word (meaning that it contains $word 
+followed by one or more characters).
+
+If you call acc_lookup() with this function as a parameter, acc_lookup() will return a list of all the words in
+the tree that are superstrings of $word.   acc_lookup uses the tree property to do this in O(log(n)) time.
+
+
+
 
 =head2 largest()
 
@@ -1652,6 +1693,13 @@ of the items returned by the iterator will be from highest to lowest.
 
 
 
+=head2 get_root()
+
+    my $root_obj = get_root();
+
+Returns a reference to the object stored at the root of the tree.
+
+
 
 =head2 print()
 
@@ -1662,7 +1710,11 @@ in the tree (by prepending the string passed-in to the object's printed value).
 
 
 
+=head1 DEPENDENCIES
 
+This module requires these other modules and libraries:
+
+Test::More (required for installation test)
 
 
 
